% This code if for the book titled: Advanced Digital Signal Processing 
% of Seismic Data by Wail A. Mousa 
% January 1, 2020.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Chapter 2 MATLAB codes %%%
%%% Figure 2.25c,26c,27c,28c and 29c Single layer events%%
clear,clc,close all
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Direct
dx=10;
x=-500:dx:500;
z=50;
v=[3200,1850,331,550];
direct_p=abs(x)/v(1);
figure
plot(x,direct_p,'k','LineWidth',2)
hold on
direct_s=abs(x)/v(2);
plot(x,direct_s,'k--','LineWidth',2)
direct_a=abs(x)/v(3);
plot(x,direct_a,'k-.','LineWidth',2)
direct_r=abs(x)/v(4);
plot(x,direct_r,'k:','LineWidth',2)
hold off
set(gca,'YDir','reverse','XAxisLocation','top')
hh=legend('Direct compressional curve {\it v_p}=3200 m/s','Direct shear curve {\it v_s}=1850 m/s',...
    'Direct air curve {\it v_a}=331 m/s','Direct Rayleigh curve {\it v_r}=550 m/s','location','south');
set(hh,'FontName','Times')
grid
xlabel('Offset (m)','FontName','Times','FontSize',16)
ylabel('Time (s)','FontName','Times','FontSize',16)
set(gcf,'PaperPositionMode','auto')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Reflections
x=-500:dx:500;
z=50;
v_p=[3000:-500:1000];
direct_p=abs(x)/v_p(1);
ref_p=sqrt(x.^2+4*z^2)/v_p(1);
figure
plot(x,ref_p,'k','LineWidth',2)
hold on
ref_p=sqrt(x.^2+4*z^2)/v_p(2);
plot(x,ref_p,'k--','LineWidth',2)
ref_p=sqrt(x.^2+4*z^2)/v_p(3);
plot(x,ref_p,'k-.','LineWidth',2)
ref_p=sqrt(x.^2+4*z^2)/v_p(4);
plot(x,ref_p,'k^-','LineWidth',2)
ref_p=sqrt(x.^2+4*z^2)/v_p(5);
plot(x,ref_p,'k:','LineWidth',2)
hold off
set(gca,'YDir','reverse','XAxisLocation','top')
hh=legend('Hyperbola at 3000 m/s','Hyperbola at 2500 m/s','Hyperbola at 2000 m/s',...
    'Hyperbola at 1500 m/s','Hyperbola at 1000 m/s','location','south');
set(hh,'FontName','Times')
grid
xlabel('Offset (m)','FontName','Times','FontSize',16)
ylabel('Time (s)','FontName','Times','FontSize',16)
set(gcf,'PaperPositionMode','auto')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Refractions
x=0:dx:500;
z=50;
v_p=[1000,2000];
theta=30*pi/180;
refraction=x/v_p(2)+2*z*cos(theta)/v_p(1);
figure
plot(x,abs(refraction),'k','LineWidth',2)
axis([0,500,0,0.6])
set(gca,'YDir','reverse','XAxisLocation','top')
grid
xlabel('Offset (m)','FontName','Times','FontSize',16)
ylabel('Time (s)','FontName','Times','FontSize',16)
set(gcf,'PaperPositionMode','auto')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Dip Reflections
x=-500:dx:500;
z=50;
theta=[0,15,30]*pi/180;
v_p=1500;
direct_p=abs(x)/v_p(1);
ref_p=sqrt(x.^2+4*z^2+4*x*z*sin(theta(1)))/v_p;
figure
plot(x,ref_p,'k','LineWidth',2)
hold on
ref_p=sqrt(x.^2+4*z^2+4*x*z*sin(theta(2)))/v_p;
plot(x,ref_p,'k--','LineWidth',2)
ref_p=sqrt(x.^2+4*z^2+4*x*z*sin(theta(3)))/v_p;
plot(x,ref_p,'k-.','LineWidth',2)
hold off
set(gca,'YDir','reverse','XAxisLocation','top')
hh=legend('Hyperbola with dip of 0^o','Hyperbola with dip of 15^o',...
    'Hyperbola with dip of 30^o','location','south');
set(hh,'FontName','Times')
grid
xlabel('Offset (m)','FontName','Times','FontSize',16)
ylabel('Time (s)','FontName','Times','FontSize',16)
axis([-500,500,0,1])
set(gcf,'PaperPositionMode','auto')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Diffractions
% positions of source,receiver and diffractor all in meters
X_source = 0;
Y_source = 0;
Z_source = 0;
X_geophone = -1000:1500;
Y_geophone = 0;
Z_geophone = 0;
X_diffractor = 200;
Y_diffractor =  0;
Z_diffractor =  1000;
% velocity of one layer
V1 =  1500; % m/s
r1 = ((X_source-X_diffractor).*(X_source-X_diffractor) +...
     (Y_source-Y_diffractor).*(Y_source-Y_diffractor)  +...
     (Z_source - Z_diffractor ).*(Z_source - Z_diffractor)).^0.5;
t1 = r1/V1;
r2 =  ((X_geophone-X_diffractor).*(X_geophone-X_diffractor) +...
     (Y_geophone-Y_diffractor).*(Y_geophone-Y_diffractor)  +...
     (Z_geophone - Z_diffractor ).*(Z_geophone - Z_diffractor)).^0.5;
t2 = r2/V1;
t = t1 + t2;
figure
plot(X_geophone,t,'k','LineWidth',2)
set(gca,'YDir','reverse','XAxisLocation','top')
grid
xlabel('Offset (m)','FontName','Times','FontSize',16)
ylabel('Time (s)','FontName','Times','FontSize',16)
axis([-1000 1500 0 2])
set(gcf,'PaperPositionMode','auto')

